@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2010  Innocent De Marchi
+ * Copyright (C) 2000-2011  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #ifndef FUNCIONS_H
 #define FUNCIONS_H
 
@@ -39,5 +38,13 @@ QIcon iconeFigura(int tipus);
  */
 QString directoriLinux();
 
+/*
+  13/02/11
+  Carrega el contingut de l'arxiu passat per paràmetre
+  a una llista (que retorna)
+  */
+QStringList llegeixArxiuALlista(QString arxiu);
+
+QString llegeixLiniaArxiu(QString arxiu, int linia);
 
 #endif // FUNCIONS_H
