@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2010  Innocent De Marchi
+ * Copyright (C) 2000-2011  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #ifndef RELLOTGE_H
 #define RELLOTGE_H
 
@@ -42,6 +41,9 @@ public:
     QString retornaTemps(int tipus=0);
     void estableixTemps(QString temps);
 
+    //Retorna l'estat del rellotge
+    bool rellotgeEnMarxa();
+
 private slots:
     void actualitzaRellotge();
 
@@ -49,6 +51,7 @@ private:
     QTimer *rellotgeQTimer;
     int hores,minuts,segons;
 
+bool p_rellotgeEnMarxa;
 
 };
 
