@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2010  Innocent De Marchi
+ * Copyright (C) 2000-2011  Innocent De Marchi
  * email: tangram.peces@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #include <QtGui>
 #include <QIcon>
 
@@ -40,7 +39,9 @@ charPathSeparator=QDir().separator();
 setMinimumSize (QSize(800,550));
 setMaximumSize(QSize(800,550));
 setWindowTitle(configuracioJoc->tradueixCadena("Crea.concurs"));
-setWindowIcon(QIcon(":/images/pecesset.png"));
+//setWindowIcon(QIcon(":/images/pecesset.png"));
+//Això no serveix de res
+//setWindowIcon(QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"pecesset.png"));
 
 //arbre de figures
     arbreFiguresTreeWidget= new QTreeWidget(this);
@@ -83,31 +84,36 @@ setWindowIcon(QIcon(":/images/pecesset.png"));
      eliminaFigura->setGeometry(0,0,40,40);
      eliminaFigura->move(80,240);
 
-     QPushButton *eliminaTotesFigures = new QPushButton(QIcon(":/images/cross.png"),"", botonsFrame);
+     QPushButton *eliminaTotesFigures = new QPushButton(
+             QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"cross.png"),"", botonsFrame);
      eliminaTotesFigures->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Elimina.Totes"));
      connect(eliminaTotesFigures,SIGNAL(clicked()),this,SLOT(eliminaTotesFiguresSlot()));
      eliminaTotesFigures->setGeometry(0,0,40,40);
      eliminaTotesFigures->move(80,280);
 
-     QPushButton *concursAtzar = new QPushButton(QIcon(":/images/conatzar.png"),"", botonsFrame);
+     QPushButton *concursAtzar = new QPushButton(
+             QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"conatzar.png"),"", botonsFrame);
      concursAtzar->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Atzar"));
      connect(concursAtzar,SIGNAL(clicked()),this,SLOT(concursAtzarSlot()));
      concursAtzar->setGeometry(0,0,40,40);
      concursAtzar->move(80,320);
 
-     QPushButton *obreConcurs = new QPushButton(QIcon(":/images/obrecon.png"),"", botonsFrame);
+     QPushButton *obreConcurs = new QPushButton(
+             QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"obrecon.png"),"", botonsFrame);
      obreConcurs->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Carrega"));
      connect(obreConcurs,SIGNAL(clicked()),this,SLOT(obreConcursSlot()));
      obreConcurs->setGeometry(0,0,40,40);
      obreConcurs->move(80,360);
 
-     QPushButton *desaConcurs = new QPushButton(QIcon(":/images/save.png"),"", botonsFrame);
+     QPushButton *desaConcurs = new QPushButton(
+             QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"save.png"),"", botonsFrame);
      desaConcurs->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Desa"));
      connect(desaConcurs,SIGNAL(clicked()),this,SLOT(desaConcursSlot()));
      desaConcurs->setGeometry(0,0,40,40);
      desaConcurs->move(80,400);
 
-     QPushButton *tanca = new QPushButton(QIcon(":/images/quit.png"),"", botonsFrame);
+     QPushButton *tanca = new QPushButton(
+             QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"surt.png"),"", botonsFrame);
      tanca->setToolTip(configuracioJoc->tradueixCadena("Tanca"));
      connect(tanca,SIGNAL(clicked()),this,SLOT(close()));
      tanca->setGeometry(0,0,40,40);
@@ -136,7 +142,8 @@ arbre->setColumnHidden(3,true);
 arbre->setColumnHidden(4,true);
 //posam la capçalera de l'arbre
 QTreeWidgetItem *item=new QTreeWidgetItem();
-item->setIcon(0,QIcon(":/images/"+configuracioJoc->nomIcone));
+// 13/02/11 Canviat per eliminar icones de resources.qrc
+item->setIcon(0,QIcon(directoriLinux()+QDir().separator()+"images"+QDir().separator()+configuracioJoc->nomIcone));
 item->setText(0,configuracioJoc->tradueixCadena(configuracioJoc->nomJocArbreFigures));
 arbre->setHeaderItem(item);
 
@@ -401,24 +408,6 @@ void CreaConcurs::tancaSlot() {
     }
 
 
-/*
-QString CreaConcurs::directoriFigures(){
-    QDir dirArxiu(QDir::homePath ());
-    if (!dirArxiu.exists("tangram")){
-         dirArxiu.mkdir( "tangram");
-      }
- return QDir::homePath ()+QDir().separator()+"tangram";
-}
-*/
-/*
-QString CreaConcurs::filtreArxiusConcurs(){
-return configuracioJoc->tradueixCadena("Concurs")+" (*."+
-                   configuracioJoc->arxiuDadesFigures.mid(0,
-                           configuracioJoc->arxiuDadesFigures.lastIndexOf("."))+
-                           QString("%1)").arg(configuracioJoc->nivellJoc) ;
-}
-*/
-
 void CreaConcurs::creaTangram(int tipusTangram){
 
         //eliminam les peces actuals
@@ -437,36 +426,8 @@ void CreaConcurs::creaTangram(int tipusTangram){
 void CreaConcurs::tradueixGUI(){
 setWindowTitle(configuracioJoc->tradueixCadena("Crea.concurs"));
 /*
-  Si això es posa aqui....el programa no funciona!!
- afegeixFigura->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Afageix"));
- eliminaFigura->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Elimina"));
- concursAtzar->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Atzar"));
- obreConcurs->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Carrega"));
- desaConcurs->setToolTip(configuracioJoc->tradueixCadena("Concurs.ToolTip.Desa"));
- tanca->setToolTip(configuracioJoc->tradueixCadena("Tanca"));
+  Si la traducció de totes les cadenes es posa aqui
+  el programa no funciona
  */
 
 }
-/*
-Retorna el icone corresponent al nivel de dificultat
-de la figura
-
-QIcon CreaConcurs::iconeFigura(int tipus){
-   switch(tipus){
-     case 1:
-       return QIcon(":/images/facil.png");
-       break;
-     case 2:
-       return QIcon(":/images/mitja.png");
-       break;
-     case 3:
-       return QIcon(":/images/dificil.png");
-       break;
-     case 4:
-       return QIcon(":/images/ok.png");
-       break;
-     default:
-       return QIcon(":/images/facil.png");
-   }
-}
-*/
