@@ -16,12 +16,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #include <QtGui>
 #include <math.h>
 
 #include "conjuntpeces.h"
 #include "comuns/constants.h"
+#include "funcions.h"
 
 
 ConjuntPeces::ConjuntPeces()
@@ -68,7 +68,7 @@ void ConjuntPeces::colocaPeces(QString dades){
   QStringList list1 = dades.split(" ");
   int tPeca,simPeca;
   float pX,pY,angle;
-   float pescala=list1.at(0).toFloat()/escala;
+  float pescala=list1.at(0).toFloat()/escala;
 
     for(int i=0;i<=arrayPeces.size()-1;i++){
       tPeca=list1.at(1+i*5).toInt();
@@ -77,6 +77,9 @@ void ConjuntPeces::colocaPeces(QString dades){
       angle=list1.at(4+i*5).toFloat();
       simPeca=list1.at(5+i*5).toInt();
 
+     //arrayPeces[i]->creaPeca(tPeca);
+     // 25/02/11 Canvis en la creació de peces
+    // arrayPeces[i]->creaPeca(tPeca,dadesPeces.value(tPeca-1));
      arrayPeces[i]->creaPeca(tPeca);
      arrayPeces[i]->setPos(pX,pY);
      if (simPeca==1){
@@ -102,7 +105,8 @@ if (dades.isNull() || dades.isEmpty()){
       pY=punt.y()+list1.at(2).toFloat();
       angle=list1.at(3).toFloat();
       simPeca=list1.at(4).toInt();
-
+     // 25/02/11 Canvis en la creació de peces
+    // arrayPeces[indexPeca]->creaPeca(tPeca,dadesPeces.value(tPeca-1));
      arrayPeces[indexPeca]->creaPeca(tPeca);
      arrayPeces[indexPeca]->setPos(pX,pY);
      if (simPeca==1){
@@ -123,6 +127,7 @@ void ConjuntPeces::recolocaPeces(QPointF punt){
     }
 }
 
+
 void ConjuntPeces::simetriaVertical(){
 //Cal assegurar-se que la figura està centrada
 centraFiguraScene();
@@ -212,7 +217,6 @@ void ConjuntPeces::centraFiguraScene(){
     }
 }
 
-
 QRectF ConjuntPeces::rectangleFigura(){
  // QRectF rectFigura=QRectF(vertexSuperiorEsquerra(),vertexInferiorDreta());
   return QRectF(vertexSuperiorEsquerra(),vertexInferiorDreta());
@@ -278,6 +282,86 @@ void ConjuntPeces::conjuntVisible(bool visible){
 Crea un conjunt segons els paràmetres passats
 */
 void ConjuntPeces::creaConjunt(int ptipusTangram, double pescala){
+  QStringList dadesTangram;
+  /* 14/02/11
+     Llista amb les dades per a la construcció de cada joc de tangram
+     -L'ordre a la llista és el codi del tangram-1
+     -Nombre de peces del joc
+     -Codis de cada peça
+   Cal tenir present que l'ordre de creación de les peces és important
+   que coincideixi amb l'ordre en què estan a l'arxiu de dades de
+   les figures.
+    NOU TANGRAM 3 */
+  dadesTangram.append("7,1,2,2,3,4,4,5"); //tangram clàssic                                       codi 1
+  dadesTangram.append("5,7,2,4,6,6"); //Tangram 5                                                 codi 2
+  dadesTangram.append("6,10,3,3,11,8,9"); //Tangram 6 I                                           codi 3
+  dadesTangram.append("7,12,1,2,2,3,3,8"); //Tangram de Fletcher (Pitàgores)                      codi 4
+  dadesTangram.append("7,3,3,13,14,15,15,16"); //Tangram del xinès també Tangram Pitagòric    codi 5
+  dadesTangram.append("7,17,1,2,3,3,5,13"); //Tangram de la saviesa Chie-No-Ita                   codi 6
+  dadesTangram.append("8,1,2,2,3,3,3,13,14"); //Tangram 8                                         codi 7
+  dadesTangram.append("9,18,18,18,19,19,19,19,20,20"); //Tangram 9                                codi 8
+  dadesTangram.append("10,21,21,22,22,23,23,1,2,2,17"); //Tangram 10                              codi 9
+  dadesTangram.append("11,24,24,25,25,23,23,23,22,22,22,22"); //Tangram 11                        codi 10
+  dadesTangram.append("12,1,2,2,2,3,13,15,26,26,26,27,27"); //Tangram rus                         codi 11
+  dadesTangram.append("13,1,1,1,2,2,2,2,2,2,2,2,2,2"); //Tangram 13                               codi 12
+  dadesTangram.append("14,1,1,2,2,2,2,3,3,4,4,4,4,5,5"); //Tangram 14                             codi 13
+  dadesTangram.append("3,28,29,30"); //Tangram de Brügner                                         codi 14
+  dadesTangram.append("6,31,32,34,35,36,21"); //Tangram Hexagrama                                 codi 15
+  dadesTangram.append("9,37,37,38,38,39,39,40,40,41"); //Tangram de l'ou                          codi 16
+  dadesTangram.append("9,42,42,42,43,43,13,1,2,5"); //Tangram del cor                             codi 17
+  dadesTangram.append("14,44,45,45,46,47,48,48,49,50,51,52,53,54,55");
+  ///Tangram Stomachion o Luculus Archimedius                              codi 18
+  dadesTangram.append("4,2,56,58,59"); //Tangram de 4 peces I                                     codi 19
+  dadesTangram.append("10,60,60,60,60,61,61,62,62,63,63"); //Tangram circular I                   codi 20
+  dadesTangram.append("7,64,65,66,21,21,24,24"); //Tangram 7 I                                    codi 21
+  //dadesTangram.append("8,67,67,67,68,69,65,64,22"); //Tangram circular de 8 peces CII             codi 22
+  dadesTangram.append("8,22,64,65,67,67,67,68,69"); //Tangram circular de 8 peces CII             codi 22
+  dadesTangram.append("6,70,71,72,1,5,3"); //Tangram 6 II                                         codi 23
+  dadesTangram.append("7,73,1,5,3,2,70,13"); //Tangram 7 II Revathi                               codi 24
+  dadesTangram.append("5,3,3,13,16,12"); //Tangram 5 I Regulus                                    codi 25
+  dadesTangram.append("7,3,3,13,12,2,5,5"); //Tangram 7 Heptex                                    codi 26
+  dadesTangram.append("5,78,74,75,76,77"); //Tangram de Sam Lloyds                                codi 27
+  dadesTangram.append("9,79,79,80,80,81,82,83,84,84"); //Tangram "los nueve tangram"              codi 28
+  dadesTangram.append("10,74,74,74,74,74,76,76,76,76,76"); //Tangram Egipci                       codi 29
+  dadesTangram.append("4,3,85,85,86"); //Tangram de 4 peces II                                    codi 30
+  dadesTangram.append("14,87,88,89,90,90,91,91,91,92,93,94,95,3,74");
+                        //Tangram Stomachion rectangular                                          codi 31
+  dadesTangram.append("11,54,45,46,47,48,46,76,90,53,45,48");
+  //Tangram Stomach (modificació de Stomachion)                                                   codi 32
+  dadesTangram.append("10,15,15,15,15,3,3,3,3,3,3"); //Tangram Elzzup (10 peces)                  codi 33
+  dadesTangram.append("8,31,32,34,35,36,21,33,57"); //Tangram dels vuit elements (8 peces)        codi 34
+  dadesTangram.append("12,1,2,2,2,3,13,15,26,96,96,97,97"); //Tangram 12 peces             codi 35
+  dadesTangram.append("5,3,1,16,4,98"); //Tangram 5 II                                     codi 36
+  dadesTangram.append("8,3,3,13,14,15,15,99,99"); //Tangram Armonigrama                       codi 37
+  dadesTangram.append("8,3,3,13,1,2,2,2,12"); //Tangramrectangular 8 peces                    codi 38
+
+//dimensionam l'array de les peces
+QStringList dadesDelTangram=dadesTangram.value(ptipusTangram-1).split(",");
+arrayPeces.resize(dadesDelTangram.value(0).toInt());
+//escales especials
+if (ptipusTangram==11){pescala=FACTOR_TR*pescala;}  //Tangram rus
+if (ptipusTangram==31){pescala=0.9*pescala;}  //Tangram Stomachion rectangular
+if (ptipusTangram==28){pescala=FACTOR_T9T*pescala;};//Tangram "los nueve tangram"
+if (ptipusTangram==35){pescala=1.5*pescala;};//Tangram 5 II
+if (ptipusTangram==38){pescala=1.3*pescala;};//Tangram rectangular
+
+//cream i carregam les peces
+for(int i=0;i<=arrayPeces.size()-1;i++){
+    //especial per a dues peces de Tangram Stomach
+    if(  (ptipusTangram==TIPUS_TANGRAM_STOMACH) &&
+       (  (dadesDelTangram.value(i+1).toInt()==76 ) || (dadesDelTangram.value(i+1).toInt()==90 ) )) {
+        arrayPeces.replace(i, new Peca(dadesDelTangram.value(i+1).toInt(),escalaStomach*pescala) ) ;
+   }
+   else
+   arrayPeces.replace(i, new Peca(dadesDelTangram.value(i+1).toInt(),pescala) ) ;
+}
+ //emplenam la propietat conjuntDePeces
+    for(int i=0;i<=arrayPeces.size()-1;i++){
+        arrayPeces[i]->conjuntDePeces=this;
+        arrayPeces[i]->indexEnElConjunt=i;
+    }
+
+/* 14/02/11
 if(arrayPeces.size()>0){ arrayPeces.clear();}
     switch (ptipusTangram){
      case TIPUS_TANGRAM_TB:
@@ -352,12 +436,12 @@ if(arrayPeces.size()>0){ arrayPeces.clear();}
         arrayPeces[i]->conjuntDePeces=this;
         arrayPeces[i]->indexEnElConjunt=i;
     }
-
+*/
  }//final creaConjunt
 
-/*
+/* 14/02/11
 Crea les peces del conjunt
-*/
+
 void ConjuntPeces::creaJocPeces(int ptipusTangram,double pescala){
 switch(ptipusTangram){    
     case TIPUS_TANGRAM_TB:
@@ -479,7 +563,7 @@ switch(ptipusTangram){
         arrayPeces.replace(4, new Peca(TX_TRAPEZI_PETIT,pescala) ) ;
         arrayPeces.replace(5, new Peca(TX_TRAPEZI_PETIT,pescala) ) ;
         arrayPeces.replace(6, new Peca(TX_PENTAGON,pescala) ) ;
-       break;    
+       break;
     case TIPUS_TANGRAM_TS:
         //Tangram de la saviesa
         arrayPeces.replace(0, new Peca(T7_QUADRAT,pescala) ) ;
@@ -542,7 +626,7 @@ switch(ptipusTangram){
         arrayPeces.replace(7, new Peca(T7_TRIANGLE_PETIT,pescala) ) ;
         arrayPeces.replace(8, new Peca(T7_TRAPEZI,pescala) ) ;
       break;
-     case TIPUS_TANGRAM_T9:
+     case TIPUS_TANGRAM_T9:escalaStomach
         arrayPeces.replace(0, new Peca(T9_TRIANGLE_EQUILATER,pescala) ) ;
         arrayPeces.replace(1, new Peca(T9_TRIANGLE_EQUILATER,pescala) ) ;
         arrayPeces.replace(2, new Peca(T9_TRIANGLE_EQUILATER,pescala) ) ;
@@ -725,3 +809,4 @@ switch(ptipusTangram){
       break;
    }//final switch
 }//final creaJocPeces
+*/
